﻿Imports System.Drawing.Text

Public Class AdvancedTextEditor

    Dim TabCount As Integer = 0

#Region "Methods"

#Region "Tabs"

    Private Sub AddTab()

        Dim Body As New RichTextBox()

        Body.Name = "Body"
        Body.Dock = DockStyle.Fill
        Body.ContextMenuStrip = ContextMenuStrip1

        Dim NewPage As New TabPage()
        TabCount += 1

        Dim DocumentText As String = "Document " & TabCount
        NewPage.Name = DocumentText
        NewPage.Text = DocumentText
        NewPage.Controls.Add(Body)

        TabControl1.TabPages.Add(NewPage)

    End Sub

    Private Sub RemoveTab()

        If Not TabControl1.TabPages.Count = 1 Then
            TabControl1.TabPages.Remove(TabControl1.SelectedTab)
        Else
            TabControl1.TabPages.Remove(TabControl1.SelectedTab)
            AddTab()
        End If

    End Sub

    Private Sub RemoveAllTabs()

        For Each Page As TabPage In TabControl1.TabPages
            TabControl1.TabPages.Remove(Page)
        Next

        AddTab()
    End Sub

    Private Sub RemoveAllTabsButThis()
        For Each Page As TabPage In TabControl1.TabPages
            If Not Page.Name = TabControl1.SelectedTab.Name Then
                TabControl1.TabPages.Remove(Page)
            End If
        Next
    End Sub


#End Region

#Region "SaveAndOpen"

    Private Sub Save()

        SaveFileDialog1.FileName = TabControl1.SelectedTab.Name
        SaveFileDialog1.Filter = "RTF|*.rtf"
        SaveFileDialog1.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        SaveFileDialog1.Title = "Save"

        If SaveFileDialog1.ShowDialog() = Windows.Forms.DialogResult.OK Then

            If SaveFileDialog1.FileName.Length > 0 Then
                GetCurrentDocument.SaveFile(SaveFileDialog1.FileName, RichTextBoxStreamType.RichText)
            End If

        End If

    End Sub

    Private Sub SaveAs()
        SaveFileDialog1.FileName = TabControl1.SelectedTab.Name
        SaveFileDialog1.Filter = "Text Files|*.txt|VB Files|*.vb|C# Files|*.cs|All Files|*.*"
        SaveFileDialog1.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        SaveFileDialog1.Title = "Save As"

        If SaveFileDialog1.ShowDialog() = Windows.Forms.DialogResult.OK Then

            If SaveFileDialog1.FileName.Length > 0 Then
                GetCurrentDocument.SaveFile(SaveFileDialog1.FileName, RichTextBoxStreamType.PlainText)
            End If

        End If
    End Sub

    Private Sub Open()
        OpenFileDialog1.InitialDirectory = My.Computer.FileSystem.SpecialDirectories.MyDocuments
        OpenFileDialog1.Filter = "RTF|*.rtf|Text Files|*.txt|VB Files|*.vb|C# Files|*.cs|All Files|*.*"

        If OpenFileDialog1.ShowDialog() = Windows.Forms.DialogResult.OK Then
            If OpenFileDialog1.FileName.Length > 0 Then
                GetCurrentDocument.LoadFile(OpenFileDialog1.FileName, RichTextBoxStreamType.PlainText)
            End If
        End If



    End Sub

#End Region

#Region "TextFunctions"

    Private Sub Undo()
        GetCurrentDocument.Undo()
    End Sub

    Private Sub Redo()
        GetCurrentDocument.Redo()
    End Sub

    Private Sub Cut()
        GetCurrentDocument.Cut()
    End Sub

    Private Sub Copy()
        GetCurrentDocument.Copy()
    End Sub

    Private Sub Paste()
        GetCurrentDocument.Paste()
    End Sub

    Private Sub SelectAll()
        GetCurrentDocument.SelectAll()
    End Sub
#End Region

#Region "General"

    Private Sub GetFontCollection()

        Dim InsFont As New InstalledFontCollection()

        For Each item As FontFamily In InsFont.Families
            ToolStripComboBox1.Items.Add(item.Name)
        Next
        ToolStripComboBox1.SelectedIndex = 0

    End Sub

    Private Sub PopulateFontSizes()
        For i = 1 To 75
            ToolStripComboBox2.Items.Add(i)
        Next

        ToolStripComboBox2.SelectedIndex = 11

    End Sub

#End Region

#End Region

#Region "Properties"

    Private ReadOnly Property GetCurrentDocument() As RichTextBox
        Get
            Return CType(TabControl1.SelectedTab.Controls.Item("Body"), RichTextBox)
        End Get
    End Property

#End Region

#Region "Events"


#Region "General"
    Private Sub AdvancedTextEditor_Load(sender As Object, e As EventArgs) Handles MyBase.Load
        AddTab()
        GetFontCollection()
        PopulateFontSizes()
    End Sub

    Private Sub Timer1_Tick(sender As Object, e As EventArgs) Handles Timer1.Tick

        If GetCurrentDocument.Text.Length > 0 Then
            ToolStripStatusLabel1.Text = GetCurrentDocument.Text.Length
        End If

    End Sub
#End Region

#Region "MenuStrip"

    Private Sub NewToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles NewToolStripMenuItem.Click
        AddTab()
    End Sub

    Private Sub OpenToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles OpenToolStripMenuItem.Click
        Open()
    End Sub

    Private Sub SaveToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles SaveToolStripMenuItem.Click
        Save()
    End Sub

    Private Sub SaveAsToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles SaveAsToolStripMenuItem.Click
        SaveAs()
    End Sub

    Private Sub ExitToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles ExitToolStripMenuItem.Click
        Me.Close()
    End Sub

    Private Sub UndoToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles UndoToolStripMenuItem.Click
        Undo()
    End Sub

    Private Sub RedoToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles RedoToolStripMenuItem.Click
        Redo()
    End Sub

    Private Sub CutToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles CutToolStripMenuItem.Click
        Cut()
    End Sub

    Private Sub CopyToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles CopyToolStripMenuItem.Click
        Copy()
    End Sub

    Private Sub PasteToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles PasteToolStripMenuItem.Click
        Paste()
    End Sub

    Private Sub SelectAllToolStripMenuItem_Click(sender As Object, e As EventArgs) Handles SelectAllToolStripMenuItem.Click
        SelectAll()
    End Sub

#End Region

#Region "Toolbar"

    Private Sub ToolStripButton1_Click(sender As Object, e As EventArgs) Handles ToolStripButton1.Click
        Dim BoldFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Bold)
        Dim RegularFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Regular)

        If GetCurrentDocument.SelectionFont.Bold Then
            GetCurrentDocument.SelectionFont = RegularFont
        Else
            GetCurrentDocument.SelectionFont = BoldFont
        End If
    End Sub

    Private Sub ToolStripButton2_Click(sender As Object, e As EventArgs) Handles ToolStripButton2.Click
        Dim ItalicFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Italic)
        Dim RegularFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Regular)

        If GetCurrentDocument.SelectionFont.Italic Then
            GetCurrentDocument.SelectionFont = RegularFont
        Else
            GetCurrentDocument.SelectionFont = ItalicFont
        End If
    End Sub

    Private Sub ToolStripButton3_Click(sender As Object, e As EventArgs) Handles ToolStripButton3.Click
        Dim UnderlineFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Underline)
        Dim RegularFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Regular)

        If GetCurrentDocument.SelectionFont.Underline Then
            GetCurrentDocument.SelectionFont = RegularFont
        Else
            GetCurrentDocument.SelectionFont = UnderlineFont
        End If
    End Sub

    Private Sub ToolStripButton4_Click(sender As Object, e As EventArgs) Handles ToolStripButton4.Click
        Dim Strikeout As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Strikeout)
        Dim RegularFont As New Font(GetCurrentDocument.SelectionFont.Name, GetCurrentDocument.SelectionFont.Size, FontStyle.Regular)

        If GetCurrentDocument.SelectionFont.Strikeout Then
            GetCurrentDocument.SelectionFont = RegularFont
        Else
            GetCurrentDocument.SelectionFont = Strikeout
        End If
    End Sub

    Private Sub ToolStripButton5_Click(sender As Object, e As EventArgs) Handles ToolStripButton5.Click
        GetCurrentDocument.SelectedText = GetCurrentDocument.SelectedText.ToUpper()
    End Sub

    Private Sub ToolStripButton6_Click(sender As Object, e As EventArgs) Handles ToolStripButton6.Click
        GetCurrentDocument.SelectedText = GetCurrentDocument.SelectedText.ToLower()
    End Sub

    Private Sub ToolStripButton7_Click(sender As Object, e As EventArgs) Handles ToolStripButton7.Click

        Dim NewFontSize As Single = GetCurrentDocument.SelectionFont.Size + 2

        Dim NewFont As New Font(GetCurrentDocument.SelectionFont.Name, NewFontSize, GetCurrentDocument.SelectionFont.Style)

        GetCurrentDocument.SelectionFont = NewFont

    End Sub

    Private Sub ToolStripButton8_Click(sender As Object, e As EventArgs) Handles ToolStripButton8.Click
        Dim NewFontSize As Single = GetCurrentDocument.SelectionFont.Size - 2

        Dim NewFont As New Font(GetCurrentDocument.SelectionFont.Name, NewFontSize, GetCurrentDocument.SelectionFont.Style)

        GetCurrentDocument.SelectionFont = NewFont
    End Sub

    Private Sub ToolStripButton9_Click(sender As Object, e As EventArgs) Handles ToolStripButton9.Click

        If ColorDialog1.ShowDialog() = Windows.Forms.DialogResult.OK Then

            GetCurrentDocument.SelectionColor = ColorDialog1.Color

        End If

    End Sub

    Private Sub HighlightGreen_Click(sender As Object, e As EventArgs) Handles HighlightGreen.Click
        GetCurrentDocument.SelectionBackColor = Color.LightGreen
    End Sub

    Private Sub HighlightOrange_Click(sender As Object, e As EventArgs) Handles HighlightOrange.Click
        GetCurrentDocument.SelectionBackColor = Color.Orange
    End Sub

    Private Sub HighlightYellow_Click(sender As Object, e As EventArgs) Handles HighlightYellow.Click
        GetCurrentDocument.SelectionBackColor = Color.Yellow
    End Sub

    Private Sub ToolStripComboBox1_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ToolStripComboBox1.SelectedIndexChanged
        Dim NewFont As New Font(ToolStripComboBox1.SelectedItem.ToString(), _
                                GetCurrentDocument.SelectionFont.Size, GetCurrentDocument.SelectionFont.Style)

        GetCurrentDocument.SelectionFont = NewFont
    End Sub

    Private Sub ToolStripComboBox2_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ToolStripComboBox2.SelectedIndexChanged
        Dim NewSize As Single = ToolStripComboBox2.SelectedItem

        Dim NewFont As New Font(GetCurrentDocument.SelectionFont.Name, NewSize, GetCurrentDocument.SelectionFont.Style)

        GetCurrentDocument.SelectionFont = NewFont
    End Sub

#End Region

#Region "LeftToolStrip"

    Private Sub NewToolStripButton_Click(sender As Object, e As EventArgs) Handles NewToolStripButton.Click
        AddTab()
    End Sub

    Private Sub RemoveTabToolStripButton_Click(sender As Object, e As EventArgs) Handles RemoveTabToolStripButton.Click
        RemoveTab()
    End Sub

    Private Sub OpenToolStripButton_Click(sender As Object, e As EventArgs) Handles OpenToolStripButton.Click
        Open()
    End Sub

    Private Sub SaveToolStripButton_Click(sender As Object, e As EventArgs) Handles SaveToolStripButton.Click
        SaveAs()
    End Sub

    Private Sub CutToolStripButton_Click(sender As Object, e As EventArgs) Handles CutToolStripButton.Click
        Cut()
    End Sub

    Private Sub CopyToolStripButton_Click(sender As Object, e As EventArgs) Handles CopyToolStripButton.Click
        Copy()
    End Sub

    Private Sub PasteToolStripButton_Click(sender As Object, e As EventArgs) Handles PasteToolStripButton.Click
        Paste()
    End Sub

#End Region

#Region "ConextMenuStrip"

    Private Sub ToolStripMenuItem1_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem1.Click
        Undo()
    End Sub

    Private Sub ToolStripMenuItem2_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem2.Click
        Redo()
    End Sub

    Private Sub ToolStripMenuItem3_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem3.Click
        Cut()
    End Sub

    Private Sub ToolStripMenuItem4_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem4.Click
        Copy()
    End Sub

    Private Sub ToolStripMenuItem5_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem5.Click
        Paste()
    End Sub

    Private Sub ToolStripMenuItem6_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem6.Click
        Save()
    End Sub

    Private Sub ToolStripMenuItem7_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem7.Click
        RemoveTab()
    End Sub

    Private Sub ToolStripMenuItem8_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem8.Click
        RemoveAllTabs()
    End Sub

    Private Sub ToolStripMenuItem9_Click(sender As Object, e As EventArgs) Handles ToolStripMenuItem9.Click
        RemoveAllTabsButThis()
    End Sub

#End Region

#End Region

End Class
